## SpecStory

## Untitled (04/03/2025, 07:53:37)

_**User**_

Periodically run `python ./cleanup.py status` to see results of lints and tests. Use `uv pip ...` not `pip ...` . Read current @TODO.md , update @CHANGELOG.md file that details all the changes we have done , update README.md so that it explains the project including the recent changes. Then run `./cleanup.py status` to see results of lints and tests, and update @TODO.md so that we have a `- [ ] item` list of things that actually are to be done next (remove things that are done, add things we should do next, re-prioritize existing items). 

---

_**Assistant**_



---



---

